==> healthrian_visualization_support-1.0.49.tar.gz: lib/src/widgets/cardio_click/connection_state_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'dart:math';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'connection_state_cardioclick.g.dart';

@CopyWith()
class ConnectionStateCardioClick extends StatelessWidget {
  const ConnectionStateCardioClick({
    super.key,
    this.width = 50,
    this.height = 50,
    this.onConnectedWidget,
    this.onDisconnectedWidget,
  });

  final double width;
  final double height;

  final Widget? onConnectedWidget;
  final Widget? onDisconnectedWidget;

  @override
  Widget build(BuildContext context) {
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder<bool>(
          stream: BLEManager().manageCardioClick.streams.connectionStateStream,
          builder: (context, snapshot) {
            final connected = snapshot.data ?? false;
            return SizedBox(
              width: width,
              height: height,
              child: connected
                  ? (onConnectedWidget ??
                      Icon(
                        Icons.check,
                        size: min(width, height),
                      ))
                  : (onDisconnectedWidget ??
                      Icon(
                        Icons.close,
                        size: min(width, height),
                      )),
            );
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.1.1.tar.gz: lib/src/widgets/cardio_click/connection_state_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'dart:math';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'connection_state_cardioclick.g.dart';

@CopyWith()
class ConnectionStateCardioClick extends StatelessWidget {
  const ConnectionStateCardioClick({
    super.key,
    this.width = 50,
    this.height = 50,
    this.onConnectedWidget,
    this.onDisconnectedWidget,
  });

  final double width;
  final double height;

  final Widget? onConnectedWidget;
  final Widget? onDisconnectedWidget;

  @override
  Widget build(BuildContext context) {
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder<bool?>(
          stream: BLEManager().manageCardioClick.streams.connectionStateStream,
          builder: (context, snapshot) {
            final connected = snapshot.data ?? false;
            return SizedBox(
              width: width,
              height: height,
              child: connected
                  ? (onConnectedWidget ??
                      Icon(
                        Icons.check,
                        size: min(width, height),
                      ))
                  : (onDisconnectedWidget ??
                      Icon(
                        Icons.close,
                        size: min(width, height),
                      )),
            );
          },
        );
      },
    );
  }
}
